@@ -12,9 +12,9 @@ from pptx import Presentation
 from pptx.chart.chart import Chart
 from pptx.dml.color import RGBColor
 from pptx.enum.dml import MSO_FILL, MSO_THEME_COLOR
-from pptx.enum.shapes import MSO_SHAPE, MSO_SHAPE_TYPE
+from pptx.enum.shapes import MSO_CONNECTOR, MSO_SHAPE, MSO_SHAPE_TYPE
 from pptx.action import ActionSetting
-from pptx.util import Inches
+from pptx.util import Emu, Inches
 
 from helpers import cls_qname, saved_pptx_path, test_pptx, test_text
 
@@ -41,6 +41,28 @@ def given_a_connector(context):
     context.shape = sld.shapes[4]
 
 
+@given('a connector and a 1 inch square picture at 0, 0')
+def given_a_connector_and_a_1_inch_square_picture_at_0_0(context):
+    prs = Presentation(test_pptx('shp-connector-props'))
+    shapes = prs.slides[1].shapes
+    context.picture = shapes[0]
+    context.connector = shapes[1]
+
+
+@given('a connector having its begin point at ({x}, {y})')
+def given_a_connector_having_its_begin_point_at_x_y(context, x, y):
+    prs = Presentation(test_pptx('shp-connector-props'))
+    sld = prs.slides[0]
+    context.connector = sld.shapes[0]
+
+
+@given('a connector having its end point at ({x}, {y})')
+def given_a_connector_having_its_end_point_at_x_y(context, x, y):
+    prs = Presentation(test_pptx('shp-connector-props'))
+    sld = prs.slides[0]
+    context.connector = sld.shapes[0]
+
+
 @given('a graphic frame')  # shouldn't matter, but this one contains a table
 def given_a_graphic_frame(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -97,6 +119,24 @@ def given_a_shape(context):
     context.shape = sld.shapes[0]
 
 
+@given('a SlideShapes object')
+def given_a_SlideShapes_object(context):
+    prs = Presentation(test_pptx('shp-shape-access'))
+    context.shapes = prs.slides[0].shapes
+
+
+@given('a SlideShapes object containing 6 shapes')
+def given_a_SlideShapes_object_containing_6_shapes(context):
+    prs = Presentation(test_pptx('shp-shape-access'))
+    context.shapes = prs.slides[0].shapes
+
+
+@given('a SlideShapes object having a {type} shape at offset {idx}')
+def given_a_SlideShapes_obj_having_type_shape_at_off_idx(context, type, idx):
+    prs = Presentation(test_pptx('shp-shape-access'))
+    context.shapes = prs.slides[1].shapes
+
+
 @given('a table')
 def given_a_table(context):
     prs = Presentation(test_pptx('shp-common-props'))
@@ -174,6 +214,26 @@ def when_I_assign_a_string_to_shape_text(context):
     context.shape.text = u'F\xf8o\nBar'
 
 
+@when('I assign {value} to connector.begin_x')
+def when_I_assign_value_to_connector_begin_x(context, value):
+    context.connector.begin_x = int(value)
+
+
+@when('I assign {value} to connector.begin_y')
+def when_I_assign_value_to_connector_begin_y(context, value):
+    context.connector.begin_y = int(value)
+
+
+@when('I assign {value} to connector.end_x')
+def when_I_assign_value_to_connector_end_x(context, value):
+    context.connector.end_x = int(value)
+
+
+@when('I assign {value} to connector.end_y')
+def when_I_assign_value_to_connector_end_y(context, value):
+    context.connector.end_y = int(value)
+
+
 @when("I assign '{value}' to shape.name")
 def when_I_assign_value_to_shape_name(context, value):
     context.shape.name = value
@@ -184,6 +244,25 @@ def when_I_assign_value_to_shape_rotation(context, value):
     context.shape.rotation = float(value)
 
 
+@when('I call connector.begin_connect(picture, 3)')
+def when_I_call_connector_begin_connect_picture_3(context):
+    connector, picture = context.connector, context.picture
+    connector.begin_connect(picture, 3)
+
+
+@when('I call connector.end_connect(picture, 3)')
+def when_I_call_connector_end_connect_picture_3(context):
+    connector, picture = context.connector, context.picture
+    connector.end_connect(picture, 3)
+
+
+@when('I call shapes.add_connector(MSO_CONNECTOR.STRAIGHT, 1, 2, 3, 4)')
+def when_I_call_shapes_add_connector(context):
+    context.connector = context.shapes.add_connector(
+        MSO_CONNECTOR.STRAIGHT, 1, 2, 3, 4
+    )
+
+
 @when("I change the left and top of the {shape_type}")
 def when_I_change_the_position_of_the_shape(context, shape_type):
     left, top = {
@@ -244,6 +323,59 @@ def when_set_fore_color_to_RGB_value(context):
 
 # then ====================================================
 
+@then('connector is a Connector object')
+def then_connector_is_a_Connector_object(context):
+    assert type(context.connector).__name__ == 'Connector'
+
+
+@then('connector.begin_x == {value}')
+def then_connector_begin_x_equals_value(context, value):
+    assert context.connector.begin_x == int(value)
+
+
+@then('connector.begin_x is an Emu object with value {x}')
+def then_connector_begin_x_is_an_Emu_object_with_value_x(context, x):
+    begin_x = context.connector.begin_x
+    assert isinstance(begin_x, Emu)
+    assert begin_x == int(x)
+
+
+@then('connector.begin_y == {value}')
+def then_connector_begin_y_equals_value(context, value):
+    assert context.connector.begin_y == int(value)
+
+
+@then('connector.begin_y is an Emu object with value {y}')
+def then_connector_begin_y_is_an_Emu_object_with_value_y(context, y):
+    begin_y = context.connector.begin_y
+    assert isinstance(begin_y, Emu)
+    assert begin_y == int(y)
+
+
+@then('connector.end_x == {value}')
+def then_connector_end_x_equals_value(context, value):
+    assert context.connector.end_x == int(value)
+
+
+@then('connector.end_x is an Emu object with value {x}')
+def then_connector_end_x_is_an_Emu_object_with_value_x(context, x):
+    end_x = context.connector.end_x
+    assert isinstance(end_x, Emu)
+    assert end_x == int(x)
+
+
+@then('connector.end_y == {value}')
+def then_connector_end_y_equals_value(context, value):
+    assert context.connector.end_y == int(value)
+
+
+@then('connector.end_y is an Emu object with value {y}')
+def then_connector_end_y_is_an_Emu_object_with_value_y(context, y):
+    end_y = context.connector.end_y
+    assert isinstance(end_y, Emu)
+    assert end_y == int(y)
+
+
 @then('shape.adjustments[0] is 0.15')
 def then_shape_adjustments_is_value(context):
     shape = context.shape
