@@ -8,7 +8,7 @@ Provides a low-level, read-only API to a serialized Open Packaging Convention
 from __future__ import absolute_import
 
 from .constants import RELATIONSHIP_TARGET_MODE as RTM
-from .oxml import oxml_fromstring
+from .oxml import parse_xml
 from .packuri import PACKAGE_URI, PackURI
 from .phys_pkg import PhysPkgReader
 from .shared import CaseInsensitiveDict
@@ -135,12 +135,12 @@ class _ContentTypeMap(object):
         Return a new |_ContentTypeMap| instance populated with the contents
         of *content_types_xml*.
         """
-        types_elm = oxml_fromstring(content_types_xml)
+        types_elm = parse_xml(content_types_xml)
         ct_map = _ContentTypeMap()
-        for o in types_elm.overrides:
-            ct_map._add_override(o.partname, o.content_type)
-        for d in types_elm.defaults:
-            ct_map._add_default(d.extension, d.content_type)
+        for o in types_elm.override_lst:
+            ct_map._add_override(o.partName, o.contentType)
+        for d in types_elm.default_lst:
+            ct_map._add_default(d.extension, d.contentType)
         return ct_map
 
     def _add_default(self, extension, content_type):
@@ -199,7 +199,7 @@ class _SerializedRelationship(object):
         self._baseURI = baseURI
         self._rId = rel_elm.rId
         self._reltype = rel_elm.reltype
-        self._target_mode = rel_elm.target_mode
+        self._target_mode = rel_elm.targetMode
         self._target_ref = rel_elm.target_ref
 
     @property
@@ -279,7 +279,7 @@ class _SerializedRelationshipCollection(object):
         """
         srels = _SerializedRelationshipCollection()
         if rels_item_xml is not None:
-            rels_elm = oxml_fromstring(rels_item_xml)
-            for rel_elm in rels_elm.Relationship:
+            rels_elm = parse_xml(rels_item_xml)
+            for rel_elm in rels_elm.relationship_lst:
                 srels._srels.append(_SerializedRelationship(baseURI, rel_elm))
         return srels
