@@ -10,6 +10,7 @@ from __future__ import (
 
 from .autoshape import AutoShapeType, Shape
 from .base import BaseShape
+from .connector import Connector
 from ..enum.shapes import PP_PLACEHOLDER
 from .graphfrm import GraphicFrame
 from ..oxml.ns import qn
@@ -28,14 +29,14 @@ def BaseShapeFactory(shape_elm, parent):
     """
     Return an instance of the appropriate shape proxy class for *shape_elm*.
     """
-    tag_name = shape_elm.tag
-    if tag_name == qn('p:sp'):
-        return Shape(shape_elm, parent)
-    if tag_name == qn('p:pic'):
-        return Picture(shape_elm, parent)
-    if tag_name == qn('p:graphicFrame'):
-        return GraphicFrame(shape_elm, parent)
-    return BaseShape(shape_elm, parent)
+    shape_cls = {
+        qn('p:cxnSp'):        Connector,
+        qn('p:sp'):           Shape,
+        qn('p:pic'):          Picture,
+        qn('p:graphicFrame'): GraphicFrame,
+    }.get(shape_elm.tag, BaseShape)
+
+    return shape_cls(shape_elm, parent)
 
 
 class _BaseShapes(ParentedElementProxy):
@@ -312,6 +313,19 @@ class SlideShapes(_BaseShapes):
         graphic_frame = self._add_chart_graphic_frame(rId, x, y, cx, cy)
         return graphic_frame
 
+    def add_connector(self, connector_type, begin_x, begin_y, end_x, end_y):
+        """
+        Add a newly created connector shape to the end of this shape tree.
+        *connector_type* is a member of the :ref:`MsoConnectorType`
+        enumeration and the end-point values are specified as EMU values. The
+        returned connector is of type *connector_type* and has begin and end
+        points as specified.
+        """
+        cxnSp = self._add_cxnSp(
+            connector_type, begin_x, begin_y, end_x, end_y
+        )
+        return self._shape_factory(cxnSp)
+
     def add_picture(self, image_file, left, top, width=None, height=None):
         """
         Add picture shape displaying image in *image_file*, where
@@ -420,6 +434,23 @@ class SlideShapes(_BaseShapes):
         graphic_frame = self._shape_factory(graphicFrame)
         return graphic_frame
 
+    def _add_cxnSp(self, connector_type, begin_x, begin_y, end_x, end_y):
+        """
+        Return a newly-added `p:cxnSp` element for a connector of
+        *connector_type* beginning at (*begin_x*, *begin_y*) and extending to
+        (*end_x*, *end_y*).
+        """
+        id_ = self._next_shape_id
+        name = 'Connector %d' % (id_-1)
+
+        flipH, flipV = begin_x > end_x, begin_y > end_y
+        x, y = min(begin_x, end_x), min(begin_y, end_y)
+        cx, cy = abs(end_x - begin_x), abs(end_y - begin_y)
+
+        return self._spTree.add_cxnSp(
+            id_, name, connector_type, x, y, cx, cy, flipH, flipV
+        )
+
     def _add_graphicFrame_containing_table(self, rows, cols, x, y, cx, cy):
         """
         Return a newly added ``<p:graphicFrame>`` element containing a table
